@@ -1,10 +1,7 @@
 const SPEC_SCRIPT: &str = include_str!("spec.sh");
 
-mod fixtures;
-
 #[macro_use]
 mod macros;
-mod argcfile;
 mod cli;
 mod compgen;
 mod escape_test;
